Crate midix_synth

Crate midix_synth 

midix_synth

Overview

This crate is NOT READY for use.

This crate has been published to park the name, and is under active development.

Most of this code, and the respective challenges of implementation comes DIRECTLY from rustysynth v1.3.3.

This crate refactors portions of rustysynth to operate cohesively with bevy_midix.

It should not be used independently just yet.

Modules

prelude
soundfont
synthesizer